package com.tzld.piaoquan.recommend.feature.service;

import com.google.common.base.Strings;
import com.tzld.piaoquan.recommend.feature.model.UserActionFeature;
import com.tzld.piaoquan.recommend.feature.model.UserFeature;
import com.tzld.piaoquan.recommend.feature.model.VideoFeature;
import com.tzld.piaoquan.recommend.feature.model.feature.UserActionFeatureProto;
import com.tzld.piaoquan.recommend.feature.model.feature.UserFeatureProto;
import com.tzld.piaoquan.recommend.feature.model.feature.VideoFeatureProto;

/**
 * @author dyp
 */
public class FeatureConverter {
    public static UserFeatureProto convert(UserFeature userFeature) {
        if (userFeature == null) {
            return null;
        }
        UserFeatureProto.Builder builder = UserFeatureProto.newBuilder();
        builder.setUid(Strings.nullToEmpty(userFeature.getUid()))
                .setUserCycleBucket7Day(Strings.nullToEmpty(userFeature.getUser_cycle_bucket_7days()))
                .setUserCycleBucket30Day(Strings.nullToEmpty(userFeature.getUser_cycle_bucket_30days()))
                .setUserShareBucket30Day(Strings.nullToEmpty(userFeature.getUser_share_bucket_30days()));

        if (userFeature.getDay1_cnt_features() != null) {
            builder.setDay1CntFeature(convert(userFeature.getDay1_cnt_features()));
        }
        if (userFeature.getDay3_cnt_features() != null) {
            builder.setDay3CntFeature(convert(userFeature.getDay3_cnt_features()));
        }
        if (userFeature.getDay7_cnt_features() != null) {
            builder.setDay7CntFeature(convert(userFeature.getDay7_cnt_features()));
        }
        if (userFeature.getMonth3_cnt_features() != null) {
            builder.setMonth3CntFeature(convert(userFeature.getMonth3_cnt_features()));
        }

        return builder.build();
    }

    private static UserActionFeatureProto convert(UserActionFeature feature) {
        if (feature == null) {
            return null;
        }
        UserActionFeatureProto.Builder builder = UserActionFeatureProto.newBuilder();
        builder.setCtr(feature.getCtr())
                .setStr(feature.getStr())
                .setRov(feature.getRov())
                .setShareCnt(Math.round(feature.getShare_cnt()))
                .setReturnCnt(Math.round(feature.getReturn_cnt()))
                .setClickCnt(Math.round(feature.getClick_cnt()))
                .setExpCnt(Math.round(feature.getExp_cnt()));

        return builder.build();
    }


    public static VideoFeatureProto convert(VideoFeature videoFeature) {
        if (videoFeature == null) {
            return null;
        }
        VideoFeatureProto.Builder builder = VideoFeatureProto.newBuilder();

        builder.setVideoId(Strings.nullToEmpty(videoFeature.getVideoId()))
                .setUpId(Strings.nullToEmpty(videoFeature.getUpId()))
                .setTags(Strings.nullToEmpty(videoFeature.getTags()))
                .setPlayLength(Strings.nullToEmpty(videoFeature.getPlayLength()))
                .setTotalTime(Strings.nullToEmpty(videoFeature.getTotalTime()))
                .setDaysSinceUpload(Strings.nullToEmpty(videoFeature.getDaysSinceUpload()));

        if (videoFeature.getDay1_cnt_features() != null) {
            builder.setVideoDay1CntFeature(convert(videoFeature.getDay1_cnt_features()));
        }
        if (videoFeature.getDay3_cnt_features() != null) {
            builder.setVideoDay3CntFeature(convert(videoFeature.getDay3_cnt_features()));
        }
        if (videoFeature.getDay7_cnt_features() != null) {
            builder.setVideoDay7CntFeature(convert(videoFeature.getDay7_cnt_features()));
        }
        if (videoFeature.getMonth3_cnt_features() != null) {
            builder.setVideoMonth3CntFeature(convert(videoFeature.getMonth3_cnt_features()));
        }

        return builder.build();
    }
}
